@@ -11,7 +11,6 @@ class Lab3Parser(ArgumentParser):
         self.add_argument("extra", nargs='*')
 
     def valid_puzzle(self, puzzle):
-        print(len(puzzle))
         return isinstance(puzzle, str) and len(puzzle) == 64
 
     def valid_player(self, player):
@@ -21,7 +20,7 @@ class Lab3Parser(ArgumentParser):
         return ["X", "O"][puzzle.count('.') % 2 == 1]
 
     def parse_args(self, args=None, namespace=None):
-        args = super(OthelloParser, self).parse_args(args, namespace)
+        args = super(Lab3Parser, self).parse_args(args, namespace)
         set_player = False
         if not self.valid_player(args.next_player):
             args.extra = [args.next_player] + args.extra
